@@ -1,5 +1,8 @@
 #include "cheapr.h"
 
+// Scalar-optimised functions for R
+// Author: Nick Christofides
+
 // Relational operators
 // define CHEAPR_OP_SWITCH
 // switch(op){
@@ -66,7 +69,7 @@ bool implicit_na_coercion(SEXP x, SEXP target){
 }
 
 R_xlen_t scalar_count(SEXP x, SEXP value, bool recursive){
-  if (cpp_vec_length(value) != 1){
+  if (vec_length(value) != 1){
     Rf_error("value must be a vector of length 1");
   }
   R_xlen_t n = Rf_xlength(x);
@@ -709,7 +712,7 @@ SEXP cpp_val_remove(SEXP x, SEXP value){
     cpp_copy_attributes(x, out, false);
     Rf_unprotect(NP);
     return out;
-    return cpp11::package("cheapr")["sset"](x, 0);
+    return cheapr_sset(x, 0);
   } else {
     R_xlen_t n = Rf_xlength(x);
     R_xlen_t n_keep = n - n_vals;
@@ -814,7 +817,7 @@ SEXP cpp_val_remove(SEXP x, SEXP value){
     default: {
       SEXP sexp_n_vals = Rf_protect(Rf_ScalarReal(n_vals)); ++NP;
       SEXP val_locs = Rf_protect(cpp_val_find(x, value, true, sexp_n_vals)); ++NP;
-      out = Rf_protect(cpp11::package("cheapr")["sset"](x, val_locs)); ++NP;
+      out = Rf_protect(cheapr_sset(x, val_locs)); ++NP;
       break;
     }
     }
