@@ -1,17 +1,23 @@
 #include "cheapr.h"
 
+// Miscellaneous functions
+// Author: Nick Christofides
+
 int int_div(int x, int y){
   return x / y;
 }
 
-[[cpp11::register]]
-R_xlen_t cpp_vec_length(SEXP x){
-  if (Rf_isFrame(x)){
+SEXP xlen_to_r(R_xlen_t x){
+  return x > integer_max_ ? Rf_ScalarReal(x) : Rf_ScalarInteger(x);
+}
+
+R_xlen_t vec_length(SEXP x){
+  if (is_df(x)){
     return cpp_df_nrow(x);
     // Is x a list?
   } else if (Rf_isVectorList(x)){
     if (Rf_inherits(x, "vctrs_rcrd")){
-      return cpp_vec_length(VECTOR_ELT(x, 0));
+      return vec_length(VECTOR_ELT(x, 0));
     } else if (Rf_inherits(x, "POSIXlt")){
       const SEXP *p_x = VECTOR_PTR_RO(x);
       R_xlen_t out = 0;
@@ -21,7 +27,7 @@ R_xlen_t cpp_vec_length(SEXP x){
       return out;
       // return Rf_xlength(VECTOR_ELT(x, 0));
     } else if (Rf_isObject(x)){
-      return Rf_asReal(cpp11::package("base")["length"](x));
+      return r_length(x);
     } else {
       return Rf_xlength(x);
     }
@@ -31,6 +37,11 @@ R_xlen_t cpp_vec_length(SEXP x){
   }
 }
 
+[[cpp11::register]]
+SEXP cpp_vector_length(SEXP x){
+  return xlen_to_r(vec_length(x));
+}
+
 int num_cores(){
   SEXP num_cores = Rf_protect(Rf_GetOption1(Rf_installChar(Rf_mkChar("cheapr.cores"))));
   int out = Rf_asInteger(num_cores);
@@ -38,10 +49,6 @@ int num_cores(){
   return out >= 1 ? out : 1;
 }
 
-SEXP xlen_to_r(R_xlen_t x){
-  return x > integer_max_ ? Rf_ScalarReal(x) : Rf_ScalarInteger(x);
-}
-
 R_xlen_t cpp_df_nrow(SEXP x){
   return Rf_xlength(Rf_getAttrib(x, R_RowNamesSymbol));
 }
@@ -52,30 +59,16 @@ SEXP r_address(SEXP x) {
   return Rf_mkChar(buf);
 }
 
+[[cpp11::register]]
+SEXP cpp_address(SEXP x){
+  return Rf_ScalarString(r_address(x));
+}
+
 [[cpp11::register]]
 SEXP r_copy(SEXP x){
   return Rf_duplicate(x);
 }
 
-// Shallow copy here means that a
-// new list is created and
-// all attributes are deep-copied
-
-// SEXP list_shallow_copy(SEXP x, bool deep_copy_attrs){
-//   if (TYPEOF(x) != VECSXP){
-//     Rf_error("Can only shallow copy lists");
-//   }
-//   R_xlen_t n = Rf_xlength(x);
-//   SEXP out = Rf_protect(Rf_allocVector(VECSXP, n));
-//   cpp_copy_attributes(x, out, deep_copy_attrs);
-//   const SEXP *p_x = VECTOR_PTR_RO(x);
-//   for (R_xlen_t i = 0; i < n; ++i){
-//     SET_VECTOR_ELT(out, i, p_x[i]);
-//   }
-//   Rf_unprotect(1);
-//   return out;
-// }
-
 // Internal-only function
 // Sum of squared-differences
 // Used in `cheapr_var()`
@@ -106,10 +99,10 @@ double var_sum_squared_diff(SEXP x, double mu){
       //   }
       //   out = temp;
       // } else {
-        for (R_xlen_t i = 0; i < n; ++i){
-          if (cheapr_is_na_int(p_x[i])) continue;
-          out += std::pow(p_x[i] - mu, 2);
-        }
+      for (R_xlen_t i = 0; i < n; ++i){
+        if (cheapr_is_na_int(p_x[i])) continue;
+        out += std::pow(p_x[i] - mu, 2);
+      }
       break;
     }
     default: {
@@ -156,29 +149,29 @@ for (R_xlen_t i = 0; i < n; ++i) {
   }                                                                                            \
 }                                                                                              \
 
-#define CHEAPR_BIN_NCODES(_IS_NA_, _NA_VAL_)                                                                    \
-for (R_xlen_t i = 0; i < n; ++i) {                                                                              \
-  p_out[i] = _NA_VAL_;                                                                                          \
-  if (!_IS_NA_(p_x[i])) {                                                                                       \
-    lo = 0;                                                                                                     \
-    hi = nb1;                                                                                                   \
-    if ( (include_oob && !include_border && (left ? p_x[i] == p_b[hi] : p_x[i] == p_b[lo])) ||                  \
-         ((include_oob && (left ? p_x[i] > p_b[hi] : p_x[i] < p_b[lo])))){                                      \
-      p_out[i] = p_b[(left ? hi : lo)];                                                                         \
-    }                                                                                                           \
-    else if (!(p_x[i] < p_b[lo] || p_x[i] > p_b[hi] ||                                                          \
-             (p_x[i] == p_b[left ? hi : lo] && !include_border))){                                              \
-      while (hi - lo >= 2) {                                                                                    \
-        cutpoint = (hi + lo)/2;                                                                                 \
-        if (p_x[i] > p_b[cutpoint] || (left && p_x[i] == p_b[cutpoint]))                                        \
-          lo = cutpoint;                                                                                        \
-        else                                                                                                    \
-          hi = cutpoint;                                                                                        \
-      }                                                                                                         \
+#define CHEAPR_BIN_NCODES(_IS_NA_, _NA_VAL_)                                                                                       \
+for (R_xlen_t i = 0; i < n; ++i) {                                                                                                 \
+  p_out[i] = _NA_VAL_;                                                                                                             \
+  if (!_IS_NA_(p_x[i])) {                                                                                                          \
+    lo = 0;                                                                                                                        \
+    hi = nb1;                                                                                                                      \
+    if ( (include_oob && !include_border && (left ? p_x[i] == p_b[hi] : p_x[i] == p_b[lo])) ||                                     \
+         ((include_oob && (left ? p_x[i] > p_b[hi] : p_x[i] < p_b[lo])))){                                                         \
+      p_out[i] = p_b[(left ? hi : lo)];                                                                                            \
+    }                                                                                                                              \
+    else if (!(p_x[i] < p_b[lo] || p_x[i] > p_b[hi] ||                                                                             \
+             (p_x[i] == p_b[left ? hi : lo] && !include_border))){                                                                 \
+      while (hi - lo >= 2) {                                                                                                       \
+        cutpoint = (hi + lo)/2;                                                                                                    \
+        if (p_x[i] > p_b[cutpoint] || (left && p_x[i] == p_b[cutpoint]))                                                           \
+          lo = cutpoint;                                                                                                           \
+        else                                                                                                                       \
+          hi = cutpoint;                                                                                                           \
+      }                                                                                                                            \
       p_out[i] = p_b[lo + (right && include_oob)];                                                                                 \
-    }                                                                                                           \
-  }                                                                                                             \
-}                                                                                                               \
+    }                                                                                                                              \
+  }                                                                                                                                \
+}                                                                                                                                  \
 
 [[cpp11::register]]
 SEXP cpp_bin(SEXP x, SEXP breaks, bool codes, bool right,
@@ -236,150 +229,6 @@ SEXP cpp_bin(SEXP x, SEXP breaks, bool codes, bool right,
   }
 }
 
-// Safe and very efficient reverse in-place (or with copy)
-// ~ O(n/2) time
-
-// matrix structure is preserved with cpp_rev
-
-[[cpp11::register]]
-SEXP cpp_rev(SEXP x, bool set){
-  R_xlen_t n = Rf_xlength(x);
-  R_xlen_t half = int_div(n, 2);
-  R_xlen_t n2 = n - 1; // Offset n for 0-indexing
-  R_xlen_t k;
-  int NP = 0;
-  bool rev_names = true;
-  bool is_altrep = ALTREP(x);
-  if (set && is_altrep){
-    Rf_warning("Cannot update an ALTREP by reference, a copy has been made.\n\tEnsure the result is assigned to an object if used in further calculations");
-  }
-  Rf_protect(x = altrep_materialise(x)); ++NP;
-
-  // altrep will have already been materialised so this should be safe
-  // and avoids a second copy
-  if (is_altrep){
-    set = true;
-  }
-  SEXP out;
-  switch (TYPEOF(x)){
-  case NILSXP: {
-    out = R_NilValue;
-    break;
-  }
-  case LGLSXP:
-  case INTSXP: {
-    out = Rf_protect(set ? x : Rf_duplicate(x)); ++NP;
-    int *p_out = INTEGER(out);
-    int left;
-    for (R_xlen_t i = 0; i < half; ++i) {
-      k = n2 - i;
-      left = p_out[i];
-      p_out[i] = p_out[k];
-      p_out[k] = left;
-    }
-    break;
-  }
-  case REALSXP: {
-    out = Rf_protect(set ? x : Rf_duplicate(x)); ++NP;
-    double *p_out = REAL(out);
-    double left;
-    for (R_xlen_t i = 0; i < half; ++i) {
-      k = n2 - i;
-      left = p_out[i];
-      p_out[i] = p_out[k];
-      p_out[k] = left;
-    }
-    break;
-  }
-  case STRSXP: {
-    out = Rf_protect(set ? x : Rf_duplicate(x)); ++NP;
-    const SEXP *p_out = STRING_PTR_RO(out);
-    for (R_xlen_t i = 0; i < half; ++i) {
-      k = n2 - i;
-      SEXP left = Rf_protect(p_out[i]);
-      SET_STRING_ELT(out, i, p_out[k]);
-      SET_STRING_ELT(out, k, left);
-      Rf_unprotect(1);
-    }
-    break;
-  }
-  case CPLXSXP: {
-    out = Rf_protect(set ? x : Rf_duplicate(x)); ++NP;
-    Rcomplex *p_out = COMPLEX(out);
-    for (R_xlen_t i = 0; i < half; ++i) {
-      k = n2 - i;
-      Rcomplex left = p_out[i];
-      SET_COMPLEX_ELT(out, i, p_out[k]);
-      SET_COMPLEX_ELT(out, k, left);
-    }
-    break;
-  }
-  case RAWSXP: {
-    out = Rf_protect(set ? x : Rf_duplicate(x)); ++NP;
-    Rbyte *p_out = RAW(out);
-    for (R_xlen_t i = 0; i < half; ++i) {
-      k = n2 - i;
-      Rbyte left = p_out[i];
-      SET_RAW_ELT(out, i, p_out[k]);
-      SET_RAW_ELT(out, k, left);
-    }
-    break;
-  }
-  default: {
-    Rf_unprotect(NP);
-    Rf_error("%s cannot handle an object of type %s", __func__, Rf_type2char(TYPEOF(x)));
-  }
-  // We can reverse data frames in-place with the below commented-out code
-  // It will not work properly though for data.tables
-
-  // case VECSXP: {
-  //   if (recursive){
-  //   rev_names = false;
-  //   out = Rf_protect(Rf_allocVector(VECSXP, n)); ++NP;
-  //   SHALLOW_DUPLICATE_ATTRIB(out, x);
-  //   for (R_xlen_t i = 0; i < n; ++i){
-  //     SET_VECTOR_ELT(out, i, cpp_rev(VECTOR_ELT(x, i), true, set));
-  //   }
-  //   break;
-  // } else if (!recursive && (!Rf_isObject(x) || Rf_isFrame(x))){
-  //   out = Rf_protect(set ? x : list_shallow_copy(x, false)); ++NP;
-  //   if (!set){
-  //     // SHALLOW_DUPLICATE_ATTRIB(out, x);
-  //     cpp_copy_names(x, out, true);
-  //   }
-  //   const SEXP *p_out = VECTOR_PTR_RO(out);
-  //   for (R_xlen_t i = 0; i < half; ++i) {
-  //     k = n2 - i;
-  //     SEXP left = Rf_protect(p_out[i]);
-  //     SET_VECTOR_ELT(out, i, p_out[k]);
-  //     SET_VECTOR_ELT(out, k, left);
-  //     Rf_unprotect(1);
-  //   }
-  //     break;
-  //   }
-  // }
-  // default: {
-  //   // set rev_names to false because catch-all r_rev() will handle that
-  //   rev_names = false;
-  //   cpp11::function r_rev = cpp11::package("base")["rev"];
-  //   if (set){
-  //     Rf_unprotect(NP);
-  //     Rf_error("Can't reverse in place here");
-  //   }
-  //   out = Rf_protect(r_rev(x)); ++NP;
-  //   break;
-  // }
-  }
-  // // If x has names, reverse them too
-  if (rev_names && !Rf_isNull(Rf_getAttrib(out, R_NamesSymbol))){
-    SEXP old_names = Rf_protect(Rf_getAttrib(out, R_NamesSymbol)); ++NP;
-    // should be okay to rev in-place here because we already copied the names
-    Rf_setAttrib(out, R_NamesSymbol, cpp_rev(old_names, true));
-  }
-  Rf_unprotect(NP);
-  return out;
-}
-
 [[cpp11::register]]
 SEXP cpp_if_else(SEXP condition, SEXP yes, SEXP no, SEXP na){
   int NP = 0; // count num protections
@@ -795,6 +644,18 @@ SEXP cpp_growth_rate(SEXP x){
   return Rf_ScalarReal(growth_rate(a, b, n));
 }
 
+SEXP create_df_row_names(int n){
+  if (n > 0){
+    SEXP out = Rf_protect(Rf_allocVector(INTSXP, 2));
+    INTEGER(out)[0] = NA_INTEGER;
+    INTEGER(out)[1] = -n;
+    Rf_unprotect(1);
+    return out;
+  } else {
+    return Rf_allocVector(INTSXP, 0);
+  }
+}
+
 // SEXP cpp_c(SEXP x){
 //   if (!Rf_isVectorList(x)){
 //     Rf_error("x must be a list of vectors");
