@@ -60,4 +60,29 @@ test_that("scalars", {
   expect_equal(na_rm(na_rm(a)), na_rm(a))
   expect_equal(na_rm(a[is.na(a)]), a[0])
 
+  # Data frame empty rows
+
+  expect_identical(na_rm(iris), iris)
+
+  expect_identical(
+    na_rm(
+      fast_df(
+        x = rep(NA, 5),
+        y = rep(NA, 5)
+      )
+    ),
+    fast_df(x = logical(), y = logical())
+  )
+
+  with_local_seed(
+    df <- new_df(x = na_insert(1:20, 7),
+                 y = na_insert(1:20, 7))
+    , 42
+  )
+
+  expect_identical(
+    list_as_df(df[rowSums(is.na(df)) < ncol(df), ]),
+    na_rm(df)
+  )
+
 })
